#
# spec file for package timescaledb
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         pgname  postgresql12%{nil}
%define         sname   timescaledb
%define         priority    %{pgname}
Version:        1.7.1
Release:        bp154.1.46
Summary:        A time-series database extension for PostgreSQL
License:        Apache-2.0
Group:          Productivity/Databases/Tools
URL:            https://www.timescale.com/
Source:         https://github.com/timescale/%{sname}/archive/%{version}/%{sname}-%{version}.tar.gz
Patch0:         clang-format9_support.diff
BuildRequires:  %{pgname}-server
BuildRequires:  %{pgname}-server-devel
BuildRequires:  clang
BuildRequires:  cmake >= 3.4
BuildRequires:  fdupes
BuildRequires:  update-alternatives
%requires_eq    %{pgname}-server
%if "%{pgname}" == ""
Name:           %{sname}
ExclusiveArch:  do_not_build
%else
Name:           %{pgname}-%{sname}
%endif

%description
TimescaleDB is a database for making SQL more scalable for
time-series data. It is engineered up from PostgreSQL, providing
automatic partitioning across time and space (partitioning key), as
well as full SQL support.

TimescaleDB is packaged as a PostgreSQL extension.

This build includes only Apache2 modules;
TSL (timescale licenced modules are not built).

This build only Apache2 modules,
TSL (timescale licenced modules are not build)

%prep
%setup -q -n %{sname}-%{version}
# Remove static .so
rm -fv %{sname}.so
%autopatch -p1

%build
export PATH="$PATH:%{_prefix}/lib/%{pgname}/bin"
# No-as-needed is mandatory for Build on Leap42/SLE12
# Force build of only Apache2(community)
%cmake -DAPACHE_ONLY=1 \
    -DCMAKE_EXE_LINKER_FLAGS="-Wl,--no-as-needed -Wl,--no-undefined -Wl,-z,now" \
    -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--no-as-needed" \
    -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--no-as-needed -Wl,--no-undefined -Wl,-z,now" \
    -DREGRESS_CHECKS=OFF \
  ..

make USE_PGXS=1 %{?_smp_mflags}

%install
export PATH="$PATH:%{_prefix}/lib/%{pgname}/bin"
%cmake_install USE_PGXS=1 install DESTDIR=%{buildroot}

%fdupes %{buildroot}/%{_datadir}/%{pgname}/extension

#%%check
# Need to be finished when we found pg_regress

%files
%defattr(-,root,root)
%license LICENSE-APACHE NOTICE
%doc README.md CONTRIBUTING.md CHANGELOG.md docs
%{_prefix}/lib/%{pgname}/%{_lib}/%{sname}*.so
%{_datadir}/%{pgname}/extension/%{sname}*

%changelog
* Wed Jun 17 2020 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 1.7.1 bugfix
  https://github.com/timescale/timescaledb/releases/tag/1.7.1
  Please note that with the release of 1.7, support for PostgreSQL
  9.6.x and 10.x are deprecated. version 2 will only support 11,12
- Packaging :
  + Activate postgresql12 supported now
  + Modifiy download url to grab a nice named tar.gz
* Tue May  5 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 1.7.0
  https://github.com/timescale/timescaledb/releases/tag/1.7.0
* Tue Mar 31 2020 Bruno Friedmann <bruno@ioda-net.ch>
  https://github.com/timescale/timescaledb/releases/tag/1.6.1
  https://github.com/timescale/timescaledb/releases/tag/1.6.0
  https://github.com/timescale/timescaledb/releases/tag/1.5.1
  https://github.com/timescale/timescaledb/releases/tag/1.5.0
  timescaledb doesn't offer support for postgresql 12 yet
- Packaging
  + spec-cleaner minimal
  + add patch to support clang version 9 clang-format9_support.diff
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 1.4.2
  https://github.com/timescale/timescaledb/releases/tag/1.2.1
  https://github.com/timescale/timescaledb/releases/tag/1.2.2
  https://github.com/timescale/timescaledb/releases/tag/1.3.0
  https://github.com/timescale/timescaledb/releases/tag/1.3.1
  https://github.com/timescale/timescaledb/releases/tag/1.3.2
  https://github.com/timescale/timescaledb/releases/tag/1.4.0
  https://github.com/timescale/timescaledb/releases/tag/1.4.1
  https://github.com/timescale/timescaledb/releases/tag/1.4.2
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- adding postgresql12 to _multibuild
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Fix grammar. Trim duplicate metadata.
* Wed Jan 30 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to release 1.2.0 (2019-01-29)
  + Postgres 11 fully supported.
  + Deprecation of adaptive chunking
  + Advanced data lifecycle management : scheduled policies
    support scheduled drop_chunks and reorder.
  + Improved performance: support for ordered appends,
    Note that ordered appends do not support ordering by time_bucket
    at this time.
  + first release to include Timescale-Licensed features.
    LICENSE_TIMESCALE. This code can be found in tsl.
    (tsl is not build on openSUSE)
  + 1.1.1
  - Fix issue when upgrading with pg_upgrade
  - Fix a segfault that sometimes appeared in long COPYs
  - Other bug and stability fixes
- Packaging :
  + Add -DAPACHE_ONLY=1 to avoid tsl code and submodules
  + Multibuild : add postgresql11 now supported
  + Deps : revisit BuildRequires
* Wed Jan 30 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to release 1.2.0 (2019-01-29)
  + Postgres 11 fully supported.
  + Deprecation of adaptive chunking
  + Advanced data lifecycle management : scheduled policies
    support scheduled drop_chunks and reorder.
  + Improved performance: support for ordered appends,
    Note that ordered appends do not support ordering by time_bucket
    at this time.
  + first release to include Timescale-Licensed features.
    LICENSE_TIMESCALE. This code can be found in tsl.
    (tsl is not build on openSUSE)
  + 1.1.1
  - Fix issue when upgrading with pg_upgrade
  - Fix a segfault that sometimes appeared in long COPYs
  - Other bug and stability fixes
- Packaging :
  + Add -DAPACHE_ONLY=1 to avoid tsl code and submodules
  + Multibuild : add postgresql11 now supported
  + Deps : revisit BuildRequires
* Wed Nov 28 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to final release version 1.0.0 (2018-10-31)
  For complete changelog see
  https://github.com/timescale/timescaledb/releases
  or CHANGELOG file packaged
- LICENSE file was renammed to LICENSE-APACHE
- Packaging renew spec with spec-cleaner -m
* Fri May 18 2018 jengelh@inai.de
- Trim redundancies from the description.
* Sat May  5 2018 bruno@ioda-net.ch
- Update to release 0.9.2 (2018-05-04)
  + High-level changes
    Fixed handling of DISCARD ALL command when parallel workers are
    involved, which sometimes caused the extension to complain it
    was not preloaded
    User permission bug fix where users locating TRIGGER permissions
    in a database could not insert data into a hypertable
  + Fixes for some issues with 32-bit architectures
- Changes for 0.9.1
  + High-level changes
    For this release only, you will need to restart the database
    before running ALTER EXTENSION
    Several edge cases regarding CTEs addressed
    Updated preloader with better error messaging and fixed edge case
    ABI compatibility with latest PostgreSQL to help catch any
    breaking changes
- Changes for 0.9.0
  + When updating your database, you should connect using
    psql with the -X flag to prevent any .psqlrc commands from
    accidentally triggering the load of a previous DB version.
  + High-level changes
    Support for multiple extension versions on different databases
    in the same PostgreSQL instance.
    This allows different databases to be updated independently
    and provides for smoother updates between versions. No
    more spurious errors in the log as the extension is being
    updated, and new versions no longer require a restart of
    the database.
  + Streamlined update process for smaller binary/package sizes
  + Significant refactoring to simplify and improve codebase,
    including improvements to error handling, security/permissions
  + Corrections to edge-case scenarios involving dropping schemas,
    hypertables, dimensions, and more
  + Correctness improvements through propagating reloptions from main
    table to chunk tables and blocking ONLY commands that try to alter
    hypertables (i.e., changes should be applied to chunks as well)
  + Addition of a migrate_data option to create_hypertable to allow
    non-empty tables to be turned into hypertables without separate
    creation & insertion steps. Note, this option may take a while
    if the original table has lots of data
  + Support for ALTER TABLE RENAME CONSTRAINT
  + Support for adjusting the number of partitions for a space dimension
  + Improvements to tablespace handling
* Tue Feb  6 2018 bruno@ioda-net.ch
- Adapt cmake ld flags (no-as-needed) for build on Leap 42x/SLE12
* Sun Feb  4 2018 bruno@ioda-net.ch
- initial package
